==> pdk-0.22.5-sources.jar: software/aws/pdk/type_safe_api/LambdaIntegration.java <==
package software.aws.pdk.type_safe_api;

/**
 * A lambda integration.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-09-20T01:23:03.575Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.aws.pdk.$Module.class, fqn = "@aws/pdk.type_safe_api.LambdaIntegration")
public class LambdaIntegration extends software.aws.pdk.type_safe_api.Integration {

    protected LambdaIntegration(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaIntegration(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param lambdaFunction This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public LambdaIntegration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction lambdaFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunction, "lambdaFunction is required") });
    }

    /**
     * Grant API Gateway permissions to invoke the lambda.
     * <p>
     * @param __0 This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void grant(final @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.IntegrationGrantProps __0) {
        software.amazon.jsii.Kernel.call(this, "grant", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(__0, "__0 is required") });
    }

    /**
     * Render the lambda integration as a snippet of OpenAPI.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.ApiGatewayIntegration render(final @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.IntegrationRenderProps props) {
        return software.amazon.jsii.Kernel.call(this, "render", software.amazon.jsii.NativeType.forClass(software.aws.pdk.type_safe_api.ApiGatewayIntegration.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}

==> pdk-0.22.16-sources.jar: software/aws/pdk/type_safe_api/LambdaIntegration.java <==
package software.aws.pdk.type_safe_api;

/**
 * A lambda integration.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-10-16T23:32:42.449Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.aws.pdk.$Module.class, fqn = "@aws/pdk.type_safe_api.LambdaIntegration")
public class LambdaIntegration extends software.aws.pdk.type_safe_api.Integration {

    protected LambdaIntegration(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaIntegration(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param lambdaFunction This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public LambdaIntegration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction lambdaFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunction, "lambdaFunction is required") });
    }

    /**
     * Grant API Gateway permissions to invoke the lambda.
     * <p>
     * @param __0 This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void grant(final @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.IntegrationGrantProps __0) {
        software.amazon.jsii.Kernel.call(this, "grant", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(__0, "__0 is required") });
    }

    /**
     * Render the lambda integration as a snippet of OpenAPI.
     * <p>
     * @param _props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.ApiGatewayIntegration render(final @org.jetbrains.annotations.NotNull software.aws.pdk.type_safe_api.IntegrationRenderProps _props) {
        return software.amazon.jsii.Kernel.call(this, "render", software.amazon.jsii.NativeType.forClass(software.aws.pdk.type_safe_api.ApiGatewayIntegration.class), new Object[] { java.util.Objects.requireNonNull(_props, "_props is required") });
    }
}
